# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.utils.pyschema` or `trulens.core.utils.constants` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.utils.constants import CIRCLE
from trulens.core.utils.pyschema import Bindings
from trulens.core.utils.pyschema import Class
from trulens.core.utils.pyschema import Function
from trulens.core.utils.pyschema import FunctionOrMethod
from trulens.core.utils.pyschema import Method
from trulens.core.utils.pyschema import Module
from trulens.core.utils.pyschema import Obj
from trulens.core.utils.pyschema import WithClassInfo
from trulens.core.utils.pyschema import builtin_init_dummy
from trulens.core.utils.pyschema import clean_attributes
from trulens.core.utils.pyschema import is_noserio
from trulens.core.utils.pyschema import noserio
from trulens.core.utils.pyschema import object_module
from trulens.core.utils.pyschema import safe_getattr



# ruff: noqa: E402, F403, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.feedback.prompts` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.feedback.prompts import AGREEMENT_SYSTEM
from trulens.feedback.prompts import ANSWER_RELEVANCE_SYSTEM
from trulens.feedback.prompts import ANSWER_RELEVANCE_USER
from trulens.feedback.prompts import COMPREHENSIVENESS_SYSTEM_PROMPT
from trulens.feedback.prompts import COMPREHENSIVENESS_USER_PROMPT
from trulens.feedback.prompts import CONTEXT_RELEVANCE_SYSTEM
from trulens.feedback.prompts import CONTEXT_RELEVANCE_USER
from trulens.feedback.prompts import CORRECT_SYSTEM
from trulens.feedback.prompts import COT_REASONS_TEMPLATE
from trulens.feedback.prompts import GENERATE_KEY_POINTS_SYSTEM_PROMPT
from trulens.feedback.prompts import GENERATE_KEY_POINTS_USER_PROMPT
from trulens.feedback.prompts import GROUNDEDNESS_REASON_TEMPLATE
from trulens.feedback.prompts import LANGCHAIN_COHERENCE_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_CONCISENESS_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_CONTROVERSIALITY_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_CORRECTNESS_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_CRIMINALITY_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_HARMFULNESS_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_HELPFULNESS_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_INSENSITIVITY_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_MALICIOUSNESS_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_MISOGYNY_SYSTEM_PROMPT
from trulens.feedback.prompts import LANGCHAIN_PROMPT_TEMPLATE_SYSTEM
from trulens.feedback.prompts import LANGCHAIN_PROMPT_TEMPLATE_USER
from trulens.feedback.prompts import (
    LANGCHAIN_PROMPT_TEMPLATE_WITH_COT_REASONS_SYSTEM,
)
from trulens.feedback.prompts import LLM_GROUNDEDNESS_FULL_PROMPT
from trulens.feedback.prompts import LLM_GROUNDEDNESS_SYSTEM
from trulens.feedback.prompts import LLM_GROUNDEDNESS_USER
from trulens.feedback.prompts import REMOVE_Y_N
from trulens.feedback.prompts import SENTIMENT_SYSTEM
from trulens.feedback.prompts import SENTIMENT_USER
from trulens.feedback.prompts import STEREOTYPES_SYSTEM_PROMPT
from trulens.feedback.prompts import STEREOTYPES_USER_PROMPT
from trulens.feedback.prompts import SYSTEM_FIND_SUPPORTING
from trulens.feedback.prompts import USER_FIND_SUPPORTING

QS_RELEVANCE_VERB_2S_TOP1: str = deprecation_utils.deprecated_str(
    "QS_RELEVANCE_VERB_2S_TOP1",
    reason="QS_RELEVANCE was removed in favor of ANSWER_RELEVANCE or CONTEXT_RELEVANCE",
)



# ruff: noqa: E402, F403, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.database.migrations` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

# NOTE: This file had contents in trulens_eval but none were public or aliases.
# Because of that, this backwards compatibility module is empty.

# TODO: Get the non-exported names here too.

from trulens.core.database.migrations import DbRevisions
from trulens.core.database.migrations import alembic_config
from trulens.core.database.migrations import downgrade_db
from trulens.core.database.migrations import get_current_db_revision
from trulens.core.database.migrations import get_revision_history
from trulens.core.database.migrations import upgrade_db



# ruff: noqa: E402
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.dashboard.react_components.record_viewer` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn(
    "trulens_eval.react_components.record_viewer"
)

from trulens.dashboard.components.record_viewer import record_viewer

record_viewer = deprecation_utils.function_moved(
    record_viewer,
    old="trulens_eval.react_components.record_viewer",
    new="trulens.dashboard.components.record_viewer",
)

__all__ = ["record_viewer"]



# ruff: noqa: E402, F403, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.feedback.embeddings` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.feedback.embeddings import Embeddings



# ruff: noqa: E401, E402, F401, F403
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.core.database`
    instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

# These are all submodules of prior trulens_eval.database and current
# trulens.core.database:
# from trulens.core.database import base
from trulens.core.database import exceptions
from trulens.core.database import legacy
from trulens.core.database import migrations
from trulens.core.database import orm
from trulens.core.database import sqlalchemy
from trulens.core.database import utils


# NOTE: There trulens_eval.database.__init__.py was blank so this backwards
# compatibility module is complete assuming the interfaces to the above imported
# submodules haven't changed.
